@@ -253,14 +253,9 @@ def edit(img, *filters, scaling = 4, demo = False):
         img = pil_to_np(img)
     return img
 
-def fits(img):
-    threshold = 64
-    print("hello")
+def fits1(img, threshold = 64):
     if img.__class__ == numpy.ndarray:
         #should change X and Y?
-        print(img.shape)
-        print(img)
-        print(img[0])
         for x in range(img.shape[0]):
             if img[x][0] > threshold or img[x][img.shape[1] - 1] > threshold:
                 return False
